@@ -43,7 +43,17 @@
 #include "AIBase.hxx"
 #include "AIManager.hxx"
 
-FGAIBase::FGAIBase() {
+
+const double FGAIBase::e = 2.71828183;
+const double FGAIBase::lbs_to_slugs = 0.031080950172;   //conversion factor
+
+
+FGAIBase::FGAIBase()
+ :  fp( NULL ),
+    model( NULL ),
+    props( NULL ),
+    manager( NULL )
+{
     _type_str = "model";
     tgt_roll = roll = tgt_pitch = tgt_yaw = tgt_vs = vs = pitch = 0.0;
     bearing = elevation = range = rdot = 0.0;
@@ -51,10 +61,11 @@ FGAIBase::FGAIBase() {
     in_range = false;
     invisible = true;
     no_roll = true;
+    life = 900;
     model_path = "";
-    model = 0;
     _otype = otNull;
     index = 0;
+    delete_me = false;
 }
 
 FGAIBase::~FGAIBase() {
@@ -63,13 +74,46 @@ FGAIBase::~FGAIBase() {
     SGPropertyNode *root = globals->get_props()->getNode("ai/models", true);
     root->removeChild(_type_str.c_str(), index);
     if (fp) delete fp;
+    fp = NULL;
 }
 
 void FGAIBase::update(double dt) {
     ft_per_deg_lat = 366468.96 - 3717.12 * cos(pos.lat()/SG_RADIANS_TO_DEGREES);
     ft_per_deg_lon = 365228.16 * cos(pos.lat() / SG_RADIANS_TO_DEGREES);
-}
 
+    // Calculate rho at altitude, using standard atmosphere
+    // For the temperature T and the pressure p,
+
+    if (altitude < 36152) {		// curve fits for the troposphere
+      T = 59 - 0.00356 * altitude;
+      p = 2116 * pow( ((T + 459.7) / 518.6) , 5.256);
+
+    } else if ( 36152 < altitude && altitude < 82345 ) {    // lower stratosphere
+      T = -70;
+      p = 473.1 * pow( e , 1.73 - (0.000048 * altitude) );
+
+    } else {                                    //  upper stratosphere
+      T = -205.05 + (0.00164 * altitude);
+      p = 51.97 * pow( ((T + 459.7) / 389.98) , -11.388);
+    }
+
+    rho = p / (1718 * (T + 459.7));
+	
+	// calculate the speed of sound at altitude
+	// a = sqrt ( g * R * (T + 459.7))
+	// where:
+	// a = speed of sound [ft/s]
+	// g = specific heat ratio, which is usually equal to 1.4  
+	// R = specific gas constant, which equals 1716 ft-lb/slug/R 
+	
+	a = sqrt ( 1.4 * 1716 * (T + 459.7));
+	
+	// calculate Mach number
+	
+	Mach = speed/a;
+	
+//	cout  << "Speed(ft/s) "<< speed <<" Altitude(ft) "<< altitude << " Mach " << Mach;
+}
 
 void FGAIBase::Transform() {
     if (!invisible) {
@@ -87,8 +131,10 @@ void FGAIBase::Transform() {
 bool FGAIBase::init() {
 
    SGPropertyNode *root = globals->get_props()->getNode("ai/models", true);
+
    index = manager->getNum(_otype) - 1;
    props = root->getNode(_type_str.c_str(), index, true);
+
    if (model_path != "") {
       model = sgLoad3DModel( globals->get_fg_root(),
 	                     model_path.c_str(),
@@ -118,7 +164,8 @@ bool FGAIBase::isa( object_type otype ) {
 
 
 void FGAIBase::bind() {
-   props->tie("id", SGRawValuePointer<int>(&id));
+   props->tie("id", SGRawValueMethods<FGAIBase,int>(*this,
+                                         &FGAIBase::_getID));
    props->tie("velocities/true-airspeed-kt",  SGRawValuePointer<double>(&speed));
    props->tie("velocities/vertical-speed-fps",
                SGRawValueMethods<FGAIBase,double>(*this,
@@ -307,3 +354,6 @@ bool FGAIBase::_isNight() {
     return (fgGetFloat("/sim/time/sun-angle-rad") > 1.57);
 }
 
+int FGAIBase::_getID() const {
+    return (int)(this);
+}
