@@ -19,7 +19,7 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
-// $Id: transmissionlist.cxx,v 1.10 2003/11/04 11:54:42 daveluff Exp $
+// $Id: transmissionlist.cxx,v 1.11 2004/04/30 00:52:11 andy Exp $
 
 
 #ifdef HAVE_CONFIG_H
@@ -174,7 +174,7 @@ string FGTransmissionList::gen_text(const atc_type &station, const TransCode cod
 			int check = 0;	// If mes gets overflowed the while loop can go infinite
 			while ( strchr(&mes[0], crej) != NULL  ) {	// ie. loop until no more occurances of crej ('@') found
 				pos = strchr( &mes[0], crej );
-				bcopy(pos, &tag[0], 3);
+				memmove(&tag[0], pos, 3);
 				tag[3] = '\0';
 				int i;
 				len = 0;
