@@ -18,7 +18,7 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
-// $Id: runways.cxx,v 1.12 2004/02/25 02:16:36 curt Exp $
+// $Id: runways.cxx,v 1.13 2004/05/28 16:24:43 curt Exp $
 
 
 #ifdef HAVE_CONFIG_H
@@ -100,8 +100,8 @@ static string GetReverseRunwayNo(string rwyno) {
     if (( tmp == "L" || tmp == "R" || tmp == "C" ) || (rwyno.size() == 1)) {
 	tmp = rwyno;
 	rwyno = "0" + tmp;
-        SG_LOG( SG_GENERAL, SG_INFO, "Standardising rwy number from " << tmp
-                                     << " to " << rwyno );
+        SG_LOG( SG_GENERAL, SG_INFO,
+                "Standardising rwy number from " << tmp << " to " << rwyno );
     }
     
     char buf[4];
@@ -121,6 +121,9 @@ static string GetReverseRunwayNo(string rwyno) {
 	} else if (rwyno.substr(2,1) == "C") {
 	    buf[2] = 'C';
 	    buf[3] = '\0';
+	} else if (rwyno.substr(2,1) == "T") {
+	    buf[2] = 'T';
+	    buf[3] = '\0';
 	} else {
 	    SG_LOG(SG_GENERAL, SG_ALERT, "Unknown runway code "
 	    << rwyno << " passed to GetReverseRunwayNo(...)");
