@@ -18,7 +18,7 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
-// $Id: xmlauto.cxx,v 1.11 2004/03/21 21:05:06 curt Exp $
+// $Id: xmlauto.cxx,v 1.13 2004/04/12 19:17:47 curt Exp $
 
 
 #include <simgear/structure/exception.hxx>
@@ -26,6 +26,7 @@
 
 #include <Main/fg_props.hxx>
 #include <Main/globals.hxx>
+#include <Main/util.hxx>
 
 #include "xmlauto.hxx"
 
@@ -34,6 +35,8 @@ FGPIDController::FGPIDController( SGPropertyNode *node ):
     debug( false ),
     y_n( 0.0 ),
     r_n( 0.0 ),
+    y_scale( 1.0 ),
+    r_scale( 1.0 ),
     Kp( 0.0 ),
     alpha( 0.1 ),
     beta( 1.0 ),
@@ -45,9 +48,7 @@ FGPIDController::FGPIDController( SGPropertyNode *node ):
     ep_n_1( 0.0 ),
     edf_n_1( 0.0 ),
     edf_n_2( 0.0 ),
-    u_n_1( 0.0 ),
-    r_scale( 1.0 ),
-    y_scale( 1.0 )
+    u_n_1( 0.0 )
 {
     int i;
     for ( i = 0; i < node->nChildren(); ++i ) {
@@ -344,10 +345,10 @@ FGPISimpleController::FGPISimpleController( SGPropertyNode *node ):
     debug( false ),
     y_n( 0.0 ),
     r_n( 0.0 ),
-    u_min( 0.0 ),
-    u_max( 0.0 ),
     y_scale( 1.0 ),
-    r_scale ( 1.0 )
+    r_scale ( 1.0 ),
+    u_min( 0.0 ),
+    u_max( 0.0 )
 {
     int i;
     for ( i = 0; i < node->nChildren(); ++i ) {
@@ -512,12 +513,12 @@ void FGPISimpleController::update( double dt ) {
 
 
 FGPredictor::FGPredictor ( SGPropertyNode *node ):
-    debug( false ),
-    ivalue( 0.0 ),
     last_value ( 999999999.9 ),
     average ( 0.0 ),
     seconds( 0.0 ),
-    filter_gain( 0.0 )
+    filter_gain( 0.0 ),
+    debug( false ),
+    ivalue( 0.0 )
 {
     int i;
     for ( i = 0; i < node->nChildren(); ++i ) {
@@ -773,7 +774,42 @@ static void update_helper( double dt ) {
     static SGPropertyNode *vs_fpm
         = fgGetNode( "/autopilot/internal/vert-speed-fpm", true );
 
-    vs_fpm->setDoubleValue( vs_fps->getDoubleValue() * 60.0 );  
+    vs_fpm->setDoubleValue( vs_fps->getDoubleValue() * 60.0 );
+
+
+    // Calculate static port pressure rate in [inhg/s].
+    // Used to determine vertical speed.
+    static SGPropertyNode *static_pressure
+	= fgGetNode( "/systems/static[0]/pressure-inhg", true );
+    static SGPropertyNode *pressure_rate
+	= fgGetNode( "/autopilot/internal/pressure-rate", true );
+    static SGPropertyNode *filter_time 
+	= fgGetNode( "/autopilot/internal/ft", true );
+
+    static double last_static_pressure = 0.0;
+    static double last_pressure_rate = 0.0;
+
+    double Tf = filter_time->getDoubleValue();
+
+    if ( dt > 0.0 && Tf > 0.0) {
+	double current_static_pressure = static_pressure->getDoubleValue();
+
+	double current_pressure_rate = 
+	    ( current_static_pressure - last_static_pressure ) / dt;
+
+	double W = dt/Tf;
+
+        // Low Pass Filter
+	current_pressure_rate =
+	    (1.0/(W + 1.0))*last_pressure_rate +
+	    ((W)/(W + 1.0))*current_pressure_rate;
+
+	pressure_rate->setDoubleValue(current_pressure_rate);
+
+	last_static_pressure = current_static_pressure;
+	last_pressure_rate = current_pressure_rate;
+    }
+
 }
 
 
