@@ -18,7 +18,7 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
-// $Id: cockpit.cxx,v 1.7 2004/01/26 20:24:29 ehofman Exp $
+// $Id: cockpit.cxx,v 1.10 2004/06/14 16:38:44 curt Exp $
 
 
 #ifdef HAVE_CONFIG_H
@@ -29,6 +29,8 @@
 #  include <windows.h>
 #endif
 
+#include <GL/glu.h>
+
 #include <stdlib.h>
 #include <stdio.h>
 #include <string.h>
@@ -721,15 +723,9 @@ void fgCockpitUpdate( void ) {
         fgUpdateHUD();
     }
 
-#define DISPLAY_COUNTER
-#ifdef DISPLAY_COUNTER
-    else
-    {
+    if ( fgGetBool( "/sim/hud/draw-fps", false ) ) {
         char buf[64];
-        float fps    =       get_frame_rate();
-//      float tris   = fps * get_vfc_tris_drawn();
-//      float culled = fps * get_vfc_tris_culled();
-//      sprintf(buf,"%-4.1f  %7.0f  %7.0f", fps, tris, culled);
+        float fps = get_frame_rate();
         sprintf(buf,"%-5.1f", fps);
 
         glMatrixMode( GL_PROJECTION );
@@ -755,7 +751,6 @@ void fgCockpitUpdate( void ) {
         glMatrixMode( GL_MODELVIEW );
         glPopMatrix();
     }
-#endif // #ifdef DISPLAY_COUNTER
     
     glViewport( 0, 0, iwidth, iheight );
 }
