@@ -54,7 +54,7 @@ INCLUDES
 DEFINITIONS
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%*/
 
-#define ID_FACTORGROUP "$Id: FGFactorGroup.h,v 1.4 2004/01/14 22:09:40 curt Exp $"
+#define ID_FACTORGROUP "$Id: FGFactorGroup.h,v 1.5 2004/06/14 11:40:45 ehofman Exp $"
 
 using std::vector;
 
@@ -69,9 +69,7 @@ class FGState;
 class FGAtmosphere;
 class FGFCS;
 class FGAircraft;
-class FGTranslation;
-class FGRotation;
-class FGPosition;
+class FGPropagate;
 class FGAuxiliary;
 class FGOutput;
 
@@ -93,13 +91,13 @@ class FGFactorGroup: public FGCoefficient
 public:
   FGFactorGroup(FGFDMExec* fdmex);
   ~FGFactorGroup();
-  
+
   bool Load(FGConfigFile *AC_cfg);
   double TotalValue(void);
   inline double GetValue(void) const { return totalValue; }
   inline double GetSD(void) { return SDtotal; }
   inline double GetFactorSD(void) { return FGCoefficient::GetSD(); }
-  
+
   void bind(FGPropertyManager* parent);
   void unbind(void);
 
@@ -113,5 +111,5 @@ private:
   FGPropertyManager *node;
   void Debug(int from);
 };
-}    
-#endif 
+}
+#endif
