@@ -55,7 +55,7 @@ INCLUDES
 
 namespace JSBSim {
 
-static const char *IdSrc = "$Id: FGOutput.cpp,v 1.8 2004/06/14 11:40:45 ehofman Exp $";
+static const char *IdSrc = "$Id: FGOutput.cpp,v 1.9 2004/09/11 12:41:05 ehofman Exp $";
 static const char *IdHdr = ID_OUTPUT;
 
 /*%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
@@ -381,9 +381,9 @@ void FGOutput::SocketOutput(void)
   socket->Clear();
   socket->Append(State->Getsim_time());
   socket->Append(Propagate->Geth());
-  socket->Append(Propagate->Getphi());
-  socket->Append(Propagate->Gettht());
-  socket->Append(Propagate->Getpsi());
+  socket->Append(Propagate->GetEuler(ePhi));
+  socket->Append(Propagate->GetEuler(eTht));
+  socket->Append(Propagate->GetEuler(ePsi));
   socket->Append(Atmosphere->GetDensity());
   socket->Append(Auxiliary->GetVt());
   socket->Append(Propagate->GetUVW(eU));
