@@ -1,8 +1,8 @@
 /*%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 
  Header:       FGGain.h
- Author:       
- Date started: 
+ Author:
+ Date started:
 
  ------------- Copyright (C)  -------------
 
@@ -53,7 +53,7 @@ INCLUDES
 DEFINITIONS
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%*/
 
-#define ID_GAIN "$Id: FGGain.h,v 1.6 2004/02/14 10:20:05 ehofman Exp $"
+#define ID_GAIN "$Id: FGGain.h,v 1.7 2004/06/14 11:40:45 ehofman Exp $"
 
 /*%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 FORWARD DECLARATIONS
@@ -94,6 +94,7 @@ CLASS DOCUMENTATION
       ROWS \<number_of_rows>
       \<lookup_value  gain_value>
       ?
+      [CLIPTO \<min> \<max> 1]
       [OUTPUT \<property>]
     \</COMPONENT>
     </pre>
@@ -158,7 +159,7 @@ CLASS DOCUMENTATION
     immediately preceded by a minus sign to invert that signal.
 
     @author Jon S. Berndt
-    @version $Id: FGGain.h,v 1.6 2004/02/14 10:20:05 ehofman Exp $
+    @version $Id: FGGain.h,v 1.7 2004/06/14 11:40:45 ehofman Exp $
 */
 
 /*%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
@@ -170,9 +171,9 @@ class FGGain  : public FGFCSComponent
 public:
   FGGain(FGFCS* fcs, FGConfigFile* AC_cfg);
   ~FGGain();
-  
+
   double GetOutputPct() const { return OutputPct; }
-  
+
   bool Run (void);
 
 private:
@@ -181,8 +182,9 @@ private:
   FGState* State;
   double Gain;
   double Min, Max;
+  double clipmin, clipmax;
   double OutputPct;
-  bool invert;
+  bool invert, clip;
   int Rows;
   FGPropertyManager* ScheduledBy;
 
