@@ -56,7 +56,7 @@ INCLUDES
 DEFINITIONS
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%*/
 
-#define ID_FLAPS "$Id: FGKinemat.h,v 1.6 2004/03/14 14:57:07 ehofman Exp $"
+#define ID_FLAPS "$Id: FGKinemat.h,v 1.7 2004/06/14 11:40:45 ehofman Exp $"
 
 /*%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 FORWARD DECLARATIONS
@@ -77,11 +77,29 @@ CLASS DECLARATION
 
 class FGKinemat  : public FGFCSComponent {
 public:
+  /** Initializer.
+      @param fcs A reference to the ccurrent flightcontrolsystem.
+      @param AC_cfg reference to the current aircraft configuration file.
+      Initializes the FGKinemat object from the given configuration
+      file. The Configuration file is expected to be at the stream
+      position where the KINEMAT object starts. Also it is expected to
+      be past the end of the current KINEMAT configuration on exit.
+   */
   FGKinemat(FGFCS* fcs, FGConfigFile* AC_cfg);
+
+  /** Destructor.
+   */
   ~FGKinemat();
   
+  /** Kinemat output value.
+      @return the current output of the kinemat object on the range of [0,1].
+   */
   double GetOutputPct() const { return OutputPct; }
     
+  /** Run method, overwrites FGModel::Run().
+      @return false on success, true on failure.
+      The routine doing the work.
+   */
   bool Run (void);
   
 private:
