@@ -18,7 +18,7 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
-// $Id: MagicCarpet.cxx,v 1.2 2004/01/12 17:39:43 curt Exp $
+// $Id: MagicCarpet.cxx,v 1.3 2004/04/01 15:27:54 curt Exp $
 
 
 #include <simgear/math/sg_geodesy.hxx>
@@ -55,7 +55,7 @@ void FGMagicCarpet::update( double dt ) {
     if (is_suspended())
       return;
 
-    int multiloop = _calc_multiloop(dt);
+    // int multiloop = _calc_multiloop(dt);
 
     double time_step = dt;
 
