@@ -3,14 +3,13 @@
 
 #include <simgear/compiler.h>
 
-#include STL_STRSTREAM
+//#include STL_STRSTREAM
+#include <sstream>
 
 #include "uiuc_parsefile.h"
 #include "uiuc_aircraft.h"
 
-#if !defined (SG_HAVE_NATIVE_SGI_COMPILERS)
-SG_USING_STD(istrstream);
-#endif
+//SG_USING_STD(istrstream);
 
 void uiuc_2DdataFileReader( string file_name, 
                             double x[100][100], 
