@@ -22,6 +22,8 @@ public:
 
     void setPropPitch(float proppitch);
 
+    void setPropFeather(int state);
+
     void setManualPitch();
 
     void calc(float density, float v, float omega,
@@ -37,8 +39,9 @@ private:
     float _beta;        // constant, ~1.48058;
     float _tc0;         // thrust "coefficient" at takeoff
     bool  _matchTakeoff; // Does _tc0 mean anything?
-    bool  _manual;   // manual pitch mode
-    float _proppitch; // prop pitch control setting (0 ~ 1.0)
+    bool  _manual;      // manual pitch mode
+    float _proppitch;   // prop pitch control setting (0 ~ 1.0)
+    float _propfeather; // prop feather control setting (0 = norm, 1 = feather)
 };
 
 }; // namespace yasim
