@@ -19,7 +19,7 @@
 // Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
 //
-// $Id: fg_init.cxx,v 1.89 2004/03/16 20:19:08 david Exp $
+// $Id: fg_init.cxx,v 1.106 2004/07/27 20:40:33 curt Exp $
 
 
 #ifdef HAVE_CONFIG_H
@@ -98,9 +98,7 @@
 #include <Instrumentation/instrument_mgr.hxx>
 #include <Model/acmodel.hxx>
 #include <AIModel/AIManager.hxx>
-#include <Navaids/fixlist.hxx>
-#include <Navaids/ilslist.hxx>
-#include <Navaids/mkrbeacons.hxx>
+#include <Navaids/navdb.hxx>
 #include <Navaids/navlist.hxx>
 #include <Replay/replay.hxx>
 #include <Scenery/scenery.hxx>
@@ -113,6 +111,7 @@
 #include <Time/sunpos.hxx>
 #include <Time/sunsolver.hxx>
 #include <Time/tmp.hxx>
+#include <Traffic/TrafficMgr.hxx>
 
 #ifdef FG_MPLAYER_AS
 #include <MultiPlayer/multiplaytxmgr.hxx>
@@ -141,6 +140,7 @@ class Sound;
 
 extern const char *default_root;
 
+
 #ifdef FG_USE_CLOUDS_3D
   SkySceneLoader *sgCloud3d;
 #endif
@@ -660,6 +660,11 @@ static double fgGetAirportElev( const string& id ) {
 }
 
 
+#if 0 
+  // 
+  // This function is never used, but maybe useful in the future ???
+  //
+
 // Preset lon/lat given an airport id
 static bool fgSetPosFromAirportID( const string& id ) {
     FGAirport a;
@@ -687,6 +692,7 @@ static bool fgSetPosFromAirportID( const string& id ) {
         return false;
     }
 }
+#endif
 
 
 // Set current tower position lon/lat given an airport id
@@ -894,12 +900,13 @@ static void fgSetDistOrAltFromGlideSlope() {
         fgSetDouble("/sim/presets/glideslope-deg", 0);
         fgSetBool("/sim/presets/onground", true);
     }                              
-}                       
+}
 
 
 // Set current_options lon/lat given an airport id and heading (degrees)
 static bool fgSetPosFromNAV( const string& id, const double& freq ) {
-    FGNav *nav = current_navlist->findByIdentAndFreq( id.c_str(), freq );
+    FGNavRecord *nav
+        = globals->get_navlist()->findByIdentAndFreq( id.c_str(), freq );
 
     // set initial position from runway and heading
     if ( nav != NULL ) {
@@ -951,7 +958,7 @@ static bool fgSetPosFromFix( const string& id ) {
     FGFix fix;
 
     // set initial position from runway and heading
-    if ( current_fixlist->query( id.c_str(), &fix ) ) {
+    if ( globals->get_fixlist()->query( id.c_str(), &fix ) ) {
         SG_LOG( SG_GENERAL, SG_INFO, "Attempting to set starting position for "
                 << id );
 
@@ -993,6 +1000,29 @@ static bool fgSetPosFromFix( const string& id ) {
         return false;
     }
 }
+ 
+static void parseWaypoints() {
+    string_list *waypoints = globals->get_initial_waypoints();
+    if (waypoints) {
+	vector<string>::iterator i;
+	for (i = waypoints->begin(); 
+	     i  != waypoints->end();
+	     i++)
+        {
+            NewWaypoint(*i);
+        }
+	// Now were done using the way points we can deallocate the
+	// memory they used
+	while (waypoints->begin() != waypoints->end()) {
+            waypoints->pop_back();
+        }
+	delete waypoints;
+	globals->set_initial_waypoints(0);
+    }
+}
+
+ 
+ 
 
 
 /**
@@ -1016,27 +1046,40 @@ fgInitNav ()
     FGRunwayList *runways = new FGRunwayList( p_runway.str() );
     globals->set_runways( runways );
 
-    SG_LOG(SG_GENERAL, SG_INFO, "Loading Navaids");
+    FGNavList *navlist = new FGNavList;
+    FGNavList *loclist = new FGNavList;
+    FGNavList *gslist = new FGNavList;
+    FGNavList *dmelist = new FGNavList;
+    FGNavList *mkrlist = new FGNavList;
 
-    SG_LOG(SG_GENERAL, SG_INFO, "  VOR/NDB");
-    current_navlist = new FGNavList;
-    SGPath p_nav( globals->get_fg_root() );
-    p_nav.append( "Navaids/default.nav" );
-    current_navlist->init( p_nav );
+    globals->set_navlist( navlist );
+    globals->set_loclist( loclist );
+    globals->set_gslist( gslist );
+    globals->set_dmelist( dmelist );
+    globals->set_mkrlist( mkrlist );
 
-    SG_LOG(SG_GENERAL, SG_INFO, "  ILS and Marker Beacons");
-    current_beacons = new FGMarkerBeacons;
-    current_beacons->init();
-    current_ilslist = new FGILSList;
-    SGPath p_ils( globals->get_fg_root() );
-    p_ils.append( "Navaids/default.ils" );
-    current_ilslist->init( p_ils );
+    if ( !fgNavDBInit(airports, navlist, loclist, gslist, dmelist, mkrlist) ) {
+        SG_LOG( SG_GENERAL, SG_ALERT,
+                "Problems loading one or more navigational database" );
+    }
+
+    if ( fgGetBool("/sim/navdb/localizers/auto-align", true) ) {
+        // align all the localizers with their corresponding runways
+        // since data sources are good for cockpit navigation
+        // purposes, but not always to the error tolerances needed to
+        // exactly place these items.
+        double threshold
+            = fgGetDouble( "/sim/navdb/localizers/auto-align-threshold-deg",
+                           5.0 );
+        fgNavDBAlignLOCwithRunway( runways, loclist, threshold );
+    }
 
     SG_LOG(SG_GENERAL, SG_INFO, "  Fixes");
-    current_fixlist = new FGFixList;
     SGPath p_fix( globals->get_fg_root() );
-    p_fix.append( "Navaids/default.fix" );
-    current_fixlist->init( p_fix );
+    p_fix.append( "Navaids/fix.dat" );
+    FGFixList *fixlist = new FGFixList;
+    fixlist->init( p_fix );
+    globals->set_fixlist( fixlist );
 
     return true;
 }
@@ -1438,8 +1481,6 @@ bool fgInitSubsystems() {
     // static const SGPropertyNode *altitude
     //     = fgGetNode("/sim/presets/altitude-ft");
 
-    FGLight *l = (FGLight *)(globals->get_subsystem("lighting"));
-
     SG_LOG( SG_GENERAL, SG_INFO, "Initialize Subsystems");
     SG_LOG( SG_GENERAL, SG_INFO, "========== ==========");
 
@@ -1516,6 +1557,7 @@ bool fgInitSubsystems() {
     globals->add_subsystem( "xml-autopilot", new FGXMLAutopilot );
     globals->add_subsystem( "route-manager", new FGRouteMgr );
 
+  
     ////////////////////////////////////////////////////////////////////
     // Initialize the view manager subsystem.
     ////////////////////////////////////////////////////////////////////
@@ -1558,6 +1600,11 @@ bool fgInitSubsystems() {
 
     globals->add_subsystem("lighting", new FGLight);
 
+    //////////////////////////////////////////////////////////////////////
+    // Initialize the 2D cloud subsystem.
+    ////////////////////////////////////////////////////////////////////
+    fgGetNode("/sim/rendering/bump-mapping", true);
+    fgSetBool("/sim/rendering/bump-mapping", false);
 
 #ifdef FG_USE_CLOUDS_3D
     ////////////////////////////////////////////////////////////////////
@@ -1568,8 +1615,8 @@ bool fgInitSubsystems() {
            = fgGetNode("/sim/presets/longitude-deg");
         static const SGPropertyNode *latitude
            = fgGetNode("/sim/presets/latitude-deg");
-        static const SGPropertyNode *altitude
-           = fgGetNode("/sim/presets/altitude-ft");
+        // static const SGPropertyNode *altitude
+        //    = fgGetNode("/sim/presets/altitude-ft");
 
         SGPath cloud_path(globals->get_fg_root());
 #if 0
@@ -1593,6 +1640,24 @@ bool fgInitSubsystems() {
     }
 #endif
 
+#ifdef ENABLE_AUDIO_SUPPORT
+    ////////////////////////////////////////////////////////////////////
+    // Initialize the sound subsystem.
+    ////////////////////////////////////////////////////////////////////
+
+    globals->set_soundmgr(new SGSoundMgr);
+    globals->get_soundmgr()->init();
+    globals->get_soundmgr()->bind();
+
+
+    ////////////////////////////////////////////////////////////////////
+    // Initialize the sound-effects subsystem.
+    ////////////////////////////////////////////////////////////////////
+
+    globals->add_subsystem("fx", new FGFX);
+    
+#endif
+
     ////////////////////////////////////////////////////////////////////
     // Initialise ATC display system
     ////////////////////////////////////////////////////////////////////
@@ -1617,36 +1682,29 @@ bool fgInitSubsystems() {
     globals->set_AI_mgr(new FGAIMgr);
     globals->get_AI_mgr()->init();
 
-
     ////////////////////////////////////////////////////////////////////
     // Initialise the AI Model Manager
     ////////////////////////////////////////////////////////////////////
-
     SG_LOG(SG_GENERAL, SG_INFO, "  AI Model Manager");
     globals->add_subsystem("ai_model", new FGAIManager);
 
 
-#ifdef ENABLE_AUDIO_SUPPORT
-    ////////////////////////////////////////////////////////////////////
-    // Initialize the sound subsystem.
-    ////////////////////////////////////////////////////////////////////
+     // It's probably a good idea to initialize the top level traffic manager
+     // After the AI and ATC systems have been initialized properly.
+     // AI Traffic manager
+     globals->add_subsystem("Traffic Manager", new FGTrafficManager);
+	     FGTrafficManager *dispatcher = 
+	     (FGTrafficManager*) globals->get_subsystem("Traffic Manager");
 
-    globals->set_soundmgr(new SGSoundMgr);
-    globals->get_soundmgr()->init();
-    globals->get_soundmgr()->bind();
-
-
-    ////////////////////////////////////////////////////////////////////
-    // Initialize the sound-effects subsystem.
-    ////////////////////////////////////////////////////////////////////
-
-    globals->add_subsystem("fx", new FGFX);
-    
-#endif
+     readXML(string(globals->get_fg_root() + string("/Traffic/fgtraffic.xml")),
+	     *dispatcher);
+     globals->get_subsystem("Traffic Manager")->init();
 
     globals->add_subsystem("instrumentation", new FGInstrumentMgr);
     globals->add_subsystem("systems", new FGSystemMgr);
 
+
+
     ////////////////////////////////////////////////////////////////////
     // Initialize the radio stack subsystem.
     ////////////////////////////////////////////////////////////////////
@@ -1752,6 +1810,12 @@ bool fgInitSubsystems() {
     globals->add_subsystem("nasal", nasal);
     nasal->init();
 
+    ////////////////////////////////////////////////////////////////////
+    // At this point we could try and parse the waypoint options
+    ///////////////////////////////////////////////////////////////////
+    parseWaypoints();
+
+
     ////////////////////////////////////////////////////////////////////////
     // End of subsystem initialization.
     ////////////////////////////////////////////////////////////////////
@@ -1786,6 +1850,7 @@ void fgReInitSubsystems()
         fgSetBool("/sim/freeze/master", true);
     }
     fgSetBool("/sim/crashed", false);
+    fgSetBool("/sim/initialised", false);
 
     // Initialize the FDM
     fgInitFDM();
@@ -1809,5 +1874,7 @@ void fgReInitSubsystems()
     if ( !freeze ) {
         fgSetBool("/sim/freeze/master", false);
     }
+    fgSetBool("/sim/initialised", true);
+    fgSetBool("/sim/sceneryloaded",false);
 }
 
