@@ -18,7 +18,7 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
-// $Id: fg_io.cxx,v 1.11 2003/11/12 10:06:18 ehofman Exp $
+// $Id: fg_io.cxx,v 1.13 2004/07/25 18:47:18 ehofman Exp $
 
 
 #include <simgear/compiler.h>
@@ -170,7 +170,10 @@ FGIO::parse_port_config( const string& config )
 	    FGRUL *rul = new FGRUL;
 	    io = rul;
         } else if ( protocol == "generic" ) {
-            FGGeneric *generic = new FGGeneric( tokens[6] );
+            int n = 6;
+            if (tokens[1] == "socket")  n++;
+            else if (tokens[1] == "file") n--;
+            FGGeneric *generic = new FGGeneric( tokens[n] );
             io = generic;
 
 #ifdef FG_MPLAYER_AS
