@@ -18,7 +18,7 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
-// $Id: fg_props.cxx,v 1.18 2004/03/16 20:19:08 david Exp $
+// $Id: fg_props.cxx,v 1.19 2004/04/24 19:28:12 curt Exp $
 
 #ifdef HAVE_CONFIG_H
 #  include <simgear/compiler.h>
@@ -29,7 +29,7 @@
 #include <simgear/timing/sg_time.hxx>
 #include <simgear/misc/sg_path.hxx>
 #include <simgear/scene/material/matlib.hxx>
-#include <simgear/sound/soundmgr.hxx>
+#include <simgear/sound/soundmgr_openal.hxx>
 
 #include STL_IOSTREAM
 
