@@ -18,7 +18,7 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
-// $Id: globals.cxx,v 1.29 2004/07/16 20:02:36 ehofman Exp $
+// $Id: globals.cxx,v 1.33 2004/09/20 13:21:52 ehofman Exp $
 
 
 #include <simgear/sound/soundmgr_openal.hxx>
@@ -42,6 +42,7 @@ FGGlobals *globals;
 
 // Constructor
 FGGlobals::FGGlobals() :
+    renderer( new FGRenderer ),
     subsystem_mgr( new SGSubsystemMgr ),
     event_mgr( new SGEventMgr ),
     sim_time_sec( 0.0 ),
@@ -95,6 +96,7 @@ FGGlobals::~FGGlobals()
     delete props;
     delete commands;
     delete io;
+    delete renderer;
   
     // make sure only to delete the initial waypoints list if it acually
     // still exists. 
@@ -157,6 +159,12 @@ void FGGlobals::set_fg_scenery (const string &scenery) {
 }
 
 
+FGRenderer *
+FGGlobals::get_renderer () const
+{
+   return renderer;
+}
+
 SGSubsystemMgr *
 FGGlobals::get_subsystem_mgr () const
 {
