@@ -19,7 +19,7 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
-// $Id: splash.cxx,v 1.10 2003/12/22 21:59:43 ehofman Exp $
+// $Id: splash.cxx,v 1.11 2004/03/31 21:10:33 andy Exp $
 
 
 #ifdef HAVE_CONFIG_H
@@ -34,10 +34,10 @@
 #  include <windows.h>
 #endif
 
-#include FG_GLUT_H
-
 #include <string.h>
 
+#include <GL/glu.h>
+
 #include <simgear/debug/logstream.hxx>
 #include <simgear/screen/texture.hxx>
 #include <simgear/math/sg_random.h>
@@ -46,6 +46,8 @@
 #include "globals.hxx"
 #include "fg_props.hxx"
 #include "splash.hxx"
+#include "fg_os.hxx"
+
 
 
 static SGTexture splash;
@@ -141,8 +143,6 @@ void fgSplashUpdate ( double progress, float alpha ) {
     glTexCoord2f(0.0, 1.0); glVertex2f(xmin, ymax); 
     glEnd();
 
-    glutSwapBuffers();
-
     glEnable(GL_DEPTH_TEST);
     glEnable(GL_LIGHTING);
     glDisable(GL_TEXTURE_2D);
