@@ -18,7 +18,7 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
-// $Id: atc610x.cxx,v 1.33 2004/03/14 23:04:32 curt Exp $
+// $Id: atc610x.cxx,v 1.37 2004/06/09 00:49:04 curt Exp $
 
 
 #ifdef HAVE_CONFIG_H
@@ -912,7 +912,7 @@ bool FGATC610x::do_radio_switches() {
 
     if ( navcom1_has_power() && comm1_serviceable->getBoolValue() ) {
         // Com1 Swap
-        int com1_swap = !((radio_switch_data[7] >> 1) & 0x01);
+        int com1_swap = ((radio_switch_data[7] >> 1) & 0x01);
         static int last_com1_swap;
         if ( com1_swap && (last_com1_swap != com1_swap) ) {
             float tmp = com1_freq->getFloatValue();
@@ -929,7 +929,7 @@ bool FGATC610x::do_radio_switches() {
 
     if ( navcom2_has_power() && comm2_serviceable->getBoolValue() ) {
         // Com2 Swap
-        int com2_swap = !((radio_switch_data[15] >> 1) & 0x01);
+        int com2_swap = ((radio_switch_data[15] >> 1) & 0x01);
         static int last_com2_swap;
         if ( com2_swap && (last_com2_swap != com2_swap) ) {
             float tmp = com2_freq->getFloatValue();
@@ -955,7 +955,7 @@ bool FGATC610x::do_radio_switches() {
 
     if ( navcom2_has_power() && nav2_serviceable->getBoolValue() ) {
         // Nav2 Swap
-        int nav2_swap = !(radio_switch_data[19] & 0x01);
+        int nav2_swap = (radio_switch_data[19] & 0x01);
         static int last_nav2_swap;
         if ( nav2_swap && (last_nav2_swap != nav2_swap) ) {
             float tmp = nav2_freq->getFloatValue();
@@ -1252,9 +1252,9 @@ bool FGATC610x::do_radio_switches() {
 
     // ADF buttons 
     fgSetInt( "/radios/kr-87/inputs/adf-btn",
-              !(radio_switch_data[23] & 0x01) );
+              (radio_switch_data[23] & 0x01) );
     fgSetInt( "/radios/kr-87/inputs/bfo-btn",
-              !(radio_switch_data[23] >> 1 & 0x01) );
+              (radio_switch_data[23] >> 1 & 0x01) );
 #ifdef CURT_HARDWARE
     fgSetInt( "/radios/kr-87/inputs/frq-btn",
               !(radio_switch_data[23] >> 2 & 0x01) );
@@ -1263,9 +1263,9 @@ bool FGATC610x::do_radio_switches() {
               (radio_switch_data[23] >> 2 & 0x01) );
 #endif
     fgSetInt( "/radios/kr-87/inputs/flt-et-btn",
-              !(radio_switch_data[23] >> 3 & 0x01) );
+              (radio_switch_data[23] >> 3 & 0x01) );
     fgSetInt( "/radios/kr-87/inputs/set-rst-btn",
-              !(radio_switch_data[23] >> 4 & 0x01) );
+              (radio_switch_data[23] >> 4 & 0x01) );
     fgSetInt( "/radios/kr-87/inputs/power-btn",
               radio_switch_data[23] >> 5 & 0x01 );
     /* cout << "adf = " << !(radio_switch_data[23] & 0x01)
@@ -1767,8 +1767,16 @@ bool FGATC610x::do_switches() {
     update_switch_matrix( board, switch_data, switch_matrix );
 
     // master switches
-    fgSetBool( "/controls/switches/master-bat", switch_matrix[board][5][1] );
-    fgSetBool( "/controls/switches/master-alt", switch_matrix[board][4][1] );
+    fgSetBool( "/controls/engines/engine[0]/master-bat",
+               switch_matrix[board][4][1] );
+    fgSetBool( "/controls/engines/engine[1]/master-bat",
+               switch_matrix[board][4][1] );
+
+    fgSetBool( "/controls/engines/engine[0]/master-alt",
+               switch_matrix[board][5][1] );
+    fgSetBool( "/controls/engines/engine[1]/master-alt",
+               switch_matrix[board][5][1] );
+
     fgSetBool( "/controls/switches/master-avionics",
                switch_matrix[board][0][3] );
 
@@ -1801,6 +1809,7 @@ bool FGATC610x::do_switches() {
         mag1 = magnetos;
         if ( mag1 == mag2 && mag2 == mag3 ) {
             fgSetInt( "/controls/engines/engine[0]/magnetos", magnetos );
+            fgSetInt( "/controls/engines/engine[1]/magnetos", magnetos );
         }
         static bool start1, start2, start3;
         start3 = start2;
@@ -1808,12 +1817,15 @@ bool FGATC610x::do_switches() {
         start1 = starter;
         if ( start1 == start2 && start2 == start3 ) {
             fgSetBool( "/controls/engines/engine[0]/starter", starter );
+            fgSetBool( "/controls/engines/engine[1]/starter", starter );
         }
     }
 
     // other toggle switches
     fgSetBool( "/controls/engines/engine[0]/fuel-pump",
                switch_matrix[board][0][2] );
+    fgSetBool( "/controls/engines/engine[1]/fuel-pump",
+               switch_matrix[board][0][2] );
     fgSetBool( "/controls/switches/flashing-beacon",
                switch_matrix[board][1][2] );
     fgSetBool( "/controls/switches/landing-light", switch_matrix[board][2][2] );
