@@ -22,7 +22,7 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
-// $Id: httpd.cxx,v 1.7 2004/01/26 20:33:30 ehofman Exp $
+// $Id: httpd.cxx,v 1.8 2004/04/25 02:06:56 curt Exp $
 
 
 #ifdef HAVE_CONFIG_H
@@ -74,7 +74,12 @@ bool FGHttpd::process() {
 
 
 bool FGHttpd::close() {
-    delete server;
+    SG_LOG( SG_IO, SG_INFO, "closing FGHttpd" );   
+
+    // the following delete causes a seg fault, gdb is not helpful.
+    // delete server;
+
+    set_enabled( false );
 
     return true;
 }
