@@ -18,7 +18,7 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
-// $Id: native_ctrls.cxx,v 1.21 2004/05/26 18:13:34 curt Exp $
+// $Id: native_ctrls.cxx,v 1.23 2004/09/10 17:53:34 curt Exp $
 
 
 #ifdef HAVE_CONFIG_H
@@ -138,6 +138,7 @@ void FGProps2NetCtrls( FGNetCtrls *net, bool honor_freezes,
         net->throttle[i] = node->getDoubleValue( "throttle", 0.0 );
 	net->mixture[i] = node->getDoubleValue( "mixture", 0.0 );
 	net->prop_advance[i] = node->getDoubleValue( "propeller-pitch", 0.0 );
+	net->condition[i] = node->getDoubleValue( "condition", 0.0 );
 	net->magnetos[i] = node->getIntValue( "magnetos", 0 );
 	if ( i == 0 ) {
 	  // cout << "Magnetos -> " << node->getIntValue( "magnetos", 0 );
@@ -186,6 +187,10 @@ void FGProps2NetCtrls( FGNetCtrls *net, bool honor_freezes,
     node = fgGetNode("/controls/gear", true);
     net->brake_left = node->getChild("brake-left")->getDoubleValue();
     net->brake_right = node->getChild("brake-right")->getDoubleValue();
+    net->copilot_brake_left
+        = node->getChild("copilot-brake-left")->getDoubleValue();
+    net->copilot_brake_right
+        = node->getChild("copilot-brake-right")->getDoubleValue();
     net->brake_parking = node->getChild("brake-parking")->getDoubleValue();
 
     net->gear_handle = fgGetBool( "controls/gear/gear-down" );
@@ -246,6 +251,7 @@ void FGProps2NetCtrls( FGNetCtrls *net, bool honor_freezes,
             htond(net->mixture[i]);
             net->fuel_pump_power[i] = htonl(net->fuel_pump_power[i]);
             htond(net->prop_advance[i]);
+            htond(net->condition[i]);
 	    net->engine_ok[i] = htonl(net->engine_ok[i]);
 	    net->mag_left_ok[i] = htonl(net->mag_left_ok[i]);
 	    net->mag_right_ok[i] = htonl(net->mag_right_ok[i]);
@@ -260,6 +266,8 @@ void FGProps2NetCtrls( FGNetCtrls *net, bool honor_freezes,
         net->num_tanks = htonl(net->num_tanks);
         htond(net->brake_left);
         htond(net->brake_right);
+        htond(net->copilot_brake_left);
+        htond(net->copilot_brake_right);
         htond(net->brake_parking);
         net->gear_handle = htonl(net->gear_handle);
         net->master_avionics = htonl(net->master_avionics);
@@ -305,6 +313,7 @@ void FGNetCtrls2Props( FGNetCtrls *net, bool honor_freezes,
             htond(net->mixture[i]);
             net->fuel_pump_power[i] = htonl(net->fuel_pump_power[i]);
             htond(net->prop_advance[i]);
+            htond(net->condition[i]);
 	    net->engine_ok[i] = htonl(net->engine_ok[i]);
 	    net->mag_left_ok[i] = htonl(net->mag_left_ok[i]);
 	    net->mag_right_ok[i] = htonl(net->mag_right_ok[i]);
@@ -318,6 +327,8 @@ void FGNetCtrls2Props( FGNetCtrls *net, bool honor_freezes,
         }
         htond(net->brake_left);
         htond(net->brake_right);
+        htond(net->copilot_brake_left);
+        htond(net->copilot_brake_right);
         htond(net->brake_parking);
         net->gear_handle = htonl(net->gear_handle);
         net->master_avionics = htonl(net->master_avionics);
@@ -356,6 +367,8 @@ void FGNetCtrls2Props( FGNetCtrls *net, bool honor_freezes,
         node->getChild( "mixture" )->setDoubleValue( net->mixture[i] );
         node->getChild( "propeller-pitch" )
             ->setDoubleValue( net->prop_advance[i] );
+        node->getChild( "condition" )
+            ->setDoubleValue( net->condition[i] );
         node->getChild( "magnetos" )->setDoubleValue( net->magnetos[i] );
 
 	// Faults
@@ -385,6 +398,10 @@ void FGNetCtrls2Props( FGNetCtrls *net, bool honor_freezes,
     if ( node != NULL ) {
         node->getChild( "brake-left" )->setDoubleValue( net->brake_left );
         node->getChild( "brake-right" )->setDoubleValue( net->brake_right );
+        node->getChild( "copilot-brake-left" )
+            ->setDoubleValue( net->copilot_brake_left );
+        node->getChild( "copilot-brake-right" )
+            ->setDoubleValue( net->copilot_brake_right );
         node->getChild( "brake-parking" )->setDoubleValue( net->brake_parking );
     }
 
