@@ -18,7 +18,7 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
-// $Id: native_fdm.cxx,v 1.20 2004/02/17 22:46:28 curt Exp $
+// $Id: native_fdm.cxx,v 1.22 2004/04/02 16:19:59 curt Exp $
 
 
 #ifdef HAVE_CONFIG_H
@@ -163,16 +163,17 @@ void FGProps2NetFDM( FGNetFDM *net, bool net_byte_order ) {
     for ( i = 0; i < net->num_engines; ++i ) {
         SGPropertyNode *node = fgGetNode("engines/engine", i, true);
         if ( node->getBoolValue( "running" ) ) {
-            net->eng_state[0] = 2;
+            net->eng_state[i] = 2;
         } else if ( node->getBoolValue( "cranking" ) ) {
-            net->eng_state[0] = 1;
+            net->eng_state[i] = 1;
         } else {
-            net->eng_state[0] = 0;
+            net->eng_state[i] = 0;
         }
         net->rpm[i] = node->getDoubleValue( "rpm" );
         net->fuel_flow[i] = node->getDoubleValue( "fuel-flow-gph" );
-        net->EGT[i] = node->getDoubleValue( "egt-degf" );
+        net->egt[i] = node->getDoubleValue( "egt-degf" );
         // cout << "egt = " << aero->EGT << endl;
+        net->mp_osi[i] = node->getDoubleValue( "mp-osi" );
         net->oil_temp[i] = node->getDoubleValue( "oil-temperature-degf" );
         net->oil_px[i] = node->getDoubleValue( "oil-pressure-psi" );
     }
@@ -249,7 +250,8 @@ void FGProps2NetFDM( FGNetFDM *net, bool net_byte_order ) {
             net->eng_state[i] = htonl(net->eng_state[i]);
             htonf(net->rpm[i]);
             htonf(net->fuel_flow[i]);
-            htonf(net->EGT[i]);
+            htonf(net->egt[i]);
+            htonf(net->mp_osi[i]);
             htonf(net->oil_temp[i]);
             htonf(net->oil_px[i]);
         }
@@ -326,7 +328,8 @@ void FGNetFDM2Props( FGNetFDM *net, bool net_byte_order ) {
             net->eng_state[i] = htonl(net->eng_state[i]);
             htonf(net->rpm[i]);
             htonf(net->fuel_flow[i]);
-            htonf(net->EGT[i]);
+            htonf(net->egt[i]);
+            htonf(net->mp_osi[i]);
             htonf(net->oil_temp[i]);
             htonf(net->oil_px[i]);
         }
@@ -420,7 +423,8 @@ void FGNetFDM2Props( FGNetFDM *net, bool net_byte_order ) {
 
 	    node->setDoubleValue( "rpm", net->rpm[i] );
 	    node->setDoubleValue( "fuel-flow-gph", net->fuel_flow[i] );
-	    node->setDoubleValue( "egt-degf", net->EGT[i] );
+	    node->setDoubleValue( "egt-degf", net->egt[i] );
+	    node->setDoubleValue( "mp-osi", net->mp_osi[i] );
 	    node->setDoubleValue( "oil-temperature-degf", net->oil_temp[i] );
 	    node->setDoubleValue( "oil-pressure-psi", net->oil_px[i] );		
 	}
