@@ -18,7 +18,7 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
-// $Id: newcache.cxx,v 1.3 2003/12/30 15:12:04 curt Exp $
+// $Id: newcache.cxx,v 1.4 2004/09/15 15:52:05 curt Exp $
 
 
 #ifdef HAVE_CONFIG_H
@@ -125,7 +125,8 @@ bool FGNewCache::make_space() {
 	for ( ; current != end; ++current ) {
 	    long index = current->first;
 	    FGTileEntry *e = current->second;
-	    if ( e->is_loaded() && (e->get_pending_models() == 0) ) {
+	    // if ( e->is_loaded() && (e->get_pending_models() == 0) ) {
+	    if ( e->is_loaded() ) {
 
                 timestamp = e->get_timestamp();
                 if ( timestamp < min_time ) {
