@@ -18,7 +18,7 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
-// $Id: tileentry.cxx,v 1.36 2004/06/08 15:32:09 ehofman Exp $
+// $Id: tileentry.cxx,v 1.40 2004/10/10 19:19:23 ehofman Exp $
 
 
 #ifdef HAVE_CONFIG_H
@@ -26,7 +26,7 @@
 #endif
 
 #include <simgear/compiler.h>
-
+#include <plib/ul.h>
 #include <Main/main.hxx>
 
 
@@ -818,6 +818,7 @@ FGTileEntry::load( const string_list &path_list, bool is_base )
                     FGDeferredModel *dm
                         = new FGDeferredModel( custom_path.str(),
                                                tile_path.str(),
+                                               tile_bucket,
                                                this, obj_trans );
                     FGTileMgr::model_ready( dm );
 
@@ -981,6 +982,19 @@ FGTileEntry::load( const string_list &path_list, bool is_base )
     }
 }
 
+void
+FGTileEntry::makeDList( ssgBranch *b )
+{
+    int nb = b->getNumKids();
+    for (int i = 0; i<nb; i++) {
+        ssgEntity *e = b->getKid(i);
+        if (e->isAKindOf(ssgTypeLeaf())) {
+            ((ssgLeaf*)e)->makeDList();
+        } else if (e->isAKindOf(ssgTypeBranch())) {
+            makeDList( (ssgBranch*)e );
+        }
+    }
+}
 
 void
 FGTileEntry::add_ssg_nodes( ssgBranch *terrain_branch,
@@ -991,6 +1005,10 @@ FGTileEntry::add_ssg_nodes( ssgBranch *terrain_branch,
 {
     // bump up the ref count so we can remove this later without
     // having ssg try to free the memory.
+#if PLIB_VERSION > 183
+    makeDList( terra_transform );
+#endif
+
     terra_transform->ref();
     terrain_branch->addKid( terra_transform );
 
